@@ -1,6 +1,6 @@
 package PDL::DSP::Windows;
 
-our $VERSION = '0.007001'; # TRIAL
+our $VERSION = '0.007002'; # TRIAL
 
 use strict;
 use warnings;
@@ -20,7 +20,7 @@ use constant {
     HAVE_GNUPLOT       => eval { require PDL::Graphics::Gnuplot; 1 }      || 0,
     USE_FFTW_DIRECTION => do {
         use version;
-        version->parse($PDL::VERSION) < version->parse('2.006_04');
+        version->parse($PDL::VERSION) <= version->parse('2.007');
     },
 };
 
@@ -689,8 +689,11 @@ sub format_param_vals {
     my @names = @{ $self->get_param_names || [] };
     return '' unless @names;
 
-    join ', ',
-        map join( ' = ', $names[$_] =~ s/^\$//r, $params[$_] ), 0 .. $#params;
+    join ', ', map {
+        my $name = $names[$_];
+        $name =~ s/^\$//;
+        join' = ', $name, $params[$_];
+    } 0 .. $#params;
 }
 
 sub format_plot_param_vals {
@@ -1398,8 +1401,8 @@ sub nuttall_per {
 }
 
 sub nuttall1 {
-  barf 'nuttall1: 1 argument expected. Got ' . scalar(@_) . ' arguments.' unless @_ == 1;
-  my ($N) = @_;
+    barf 'nuttall1: 1 argument expected. Got ' . scalar(@_) . ' arguments.' unless @_ == 1;
+    my ($N) = @_;
     my $cx = (cos(zeroes($N)->xlinvals(0,TPI)));
 
     (0.211536) +  ($cx * ((-0.449584) +  ($cx * (0.288464 + $cx * (-0.050416)  ))));
@@ -1413,20 +1416,20 @@ sub nuttall1_per {
 }
 
 sub parzen {
-  barf 'parzen: 1 argument expected. Got ' . scalar(@_) . ' arguments.' unless @_ == 1;
-  my ($N) = @_;
+    barf 'parzen: 1 argument expected. Got ' . scalar(@_) . ' arguments.' unless @_ == 1;
+    my ($N) = @_;
 
-  my $x = zeroes($N)->xlinvals( -1, 1 );
+    my $x = zeroes($N)->xlinvals( -1, 1 );
 
-  my $x1 = $x->where( $x <= -0.5 );
-  my $x2 = $x->where( ( $x < 0.5 ) & ( $x > -0.5 ) );
-  my $x3 = $x->where( $x >= 0.5 );
+    my $x1 = $x->where( $x <= -0.5 );
+    my $x2 = $x->where( ( $x < 0.5 ) & ( $x > -0.5 ) );
+    my $x3 = $x->where( $x >= 0.5 );
 
-  $x1 .= 2 * ( 1 - abs($x1) ) ** 3;
-  $x2 .= 1 - 6 * $x2 ** 2 * ( 1 - abs($x2) );
-  $x3 .= $x1->slice('-1:0:-1');
+    $x1 .= 2 * ( 1 - abs($x1) ) ** 3;
+    $x2 .= 1 - 6 * $x2 ** 2 * ( 1 - abs($x2) );
+    $x3 .= $x1->slice('-1:0:-1');
 
-  $x;
+    $x;
 }
 
 sub parzen_per {
